@@ -185,13 +185,11 @@ class Joint:
 
 
 class Mechanism:
-    def __init__(self, vectors=None, input_vector=None, loops=None, pos=None, vel=None, acc=None,
-                 guess=None):
+    def __init__(self, vectors=None, origin=None, loops=None, pos=None, vel=None, acc=None, guess=None):
         """
         :param vectors: tup, list; A list or tuple of vector objects.
-        :param input_vector: Vector; A vector object in which pos, vel, and acc data gets past to in the loop
-            equation. The joint at the tail of the Vector object is taken to be the origin for all the data in joints.
-            This vector is typically the crank of the mechanism.
+        :param origin: Joint; The joint object to be taken as the origin. This will be assumed to be fixed and forces
+                       a fixed frame of reference.
         :param loops: func; This is a function of loop equations of that returns a flattened ndarray. This function is
             used in fsolve. See examples for how these loop equations are structured.
         :param pos: int, float, ndarray; Value(s) of pos for the input vector. This gets past as a second argument
@@ -211,7 +209,7 @@ class Mechanism:
         velocities: A list of Velocity objects.
         accelerations: A list of Acceleration objects.
         """
-        self.vectors, self.input_vector = vectors, input_vector
+        self.vectors, self.origin = vectors, origin
         joints = set()
         for v in vectors:
             joints.update(v.joints)
@@ -232,7 +230,7 @@ class Mechanism:
         self.dic = {v: v for v in self.vectors}
 
         assert self.vectors, 'Vector argument not defined.'
-        assert self.input_vector, 'Input vector argument not defined.'
+        assert self.origin, 'Input vector argument not defined.'
         assert self.loops, 'Loops argument not defined.'
         assert self.pos is not None, "pos argument must be defined."
 
@@ -254,7 +252,7 @@ class Mechanism:
         Fixes the positions of all the joints assuming that all vectors are defined locally, meaning that each vector's
         length, angle, r_dot, omega, r_ddot, and alpha are known.
         """
-        origin = self.input_vector.joints[0]
+        origin = self.origin
         origin.fix_position(0, 0)
 
         attached_to_origin = []
@@ -292,7 +290,7 @@ class Mechanism:
         Fixes the velocity of all the joints assuming that all vectors are defined locally, meaning that each vector's
         length, angle, r_dot, omega, r_ddot, and alpha are known.
         """
-        origin = self.input_vector.joints[0]
+        origin = self.origin
         origin.fix_velocity(0, 0)
 
         attached_to_origin = []
@@ -330,7 +328,7 @@ class Mechanism:
         Fixes the accelerations of all the joints assuming that all vectors are defined locally, meaning that the
         vector's length, angle, r_dot, omega, r_ddot, and alpha are known.
         """
-        origin = self.input_vector.joints[0]
+        origin = self.origin
         origin.fix_acceleration(0, 0)
 
         attached_to_origin = []
@@ -460,18 +458,22 @@ class Mechanism:
             print('')
             Data(joint_data, headers=['Joint', 'Mag', 'Angle', 'x', 'y']).print(table=True)
 
-    def plot(self, velocity=False, acceleration=False, show_joints=True, cushion=1):
+    def plot(self, velocity=False, acceleration=False, show_joints=True, grid=True, cushion=1):
         """
         Plots the instance of the mechanism; calculate() method must be called before calling this method.
 
         :param velocity: bool; Plots velocity vectors if True
         :param acceleration: bool; Plots acceleration vectors if True
         :param show_joints: Adds joint labels to the plot (only if velocity=False and acceleration=False)
+        :param grid: bool; Add the grid if true.
         :param cushion: int, float; The thickness of the cushion around the plot.
         """
         fig, ax = plt.subplots()
         ax.set_aspect('equal')
 
+        if grid:
+            ax.grid(zorder=1)
+
         y_values = [j.y_pos for j in self.joints]
         x_values = [j.x_pos for j in self.joints]
         min_y, max_y = min(y_values), max(y_values)
@@ -620,16 +622,20 @@ class Mechanism:
 
         return (x_min, x_max), (y_min, y_max)
 
-    def get_animation(self, cushion=1):
+    def get_animation(self, grid=True, cushion=1):
         # Todo: A step value could be added here to adjust speed
         """
         :param: cushion: int; Add a cushion around the plot.
+        :param: grid: bool; Add the grid if true.
         :return: An animation, figure, and axes object.
         """
         fig, ax = plt.subplots()
         ax.set_aspect('equal')
         x_limits, y_limits = self.get_bounds()
 
+        if grid:
+            ax.grid(zorder=1)
+
         ax.set_xlim(x_limits[0] - cushion, x_limits[1] + cushion)
         ax.set_ylim(y_limits[0] - cushion, y_limits[1] + cushion)
 
